@@ -1,6 +1,6 @@
 
 # Copyright (C) 2012 - 2022  JJ Allaire, Dirk Eddelbuettel and Romain Francois
-# Copyright (C) 2023         JJ Allaire, Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
+# Copyright (C) 2023 - 2024  JJ Allaire, Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
 #
 # This file is part of Rcpp.
 #
@@ -560,6 +560,13 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
         list(env = list(PKG_CXXFLAGS ="-std=c++23"))
 }
 
+# built-in C++26 plugin for C++26
+.plugins[["cpp26"]] <- function() {
+    if (getRversion() >= "4.5")         # with recent R versions, R can decide
+        list(env = list(USE_CXX26 = "yes"))
+    else
+        list(env = list(PKG_CXXFLAGS ="-std=c++26"))
+}
 
 ## built-in C++1z plugin for C++17 standard under development
 ## note that as of Feb 2017 this is taken to be a moving target
@@ -579,10 +586,74 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
     list(env = list(PKG_CXXFLAGS ="-std=c++2b"))
 }
 
+.openmpPluginDefault <- function() {
+    list(env = list(PKG_CXXFLAGS = "-fopenmp", PKG_LIBS = "-fopenmp"))
+}
+
+.openmpPluginDarwin <- function() {
+
+    # generate a test script for compilation
+    script <- tempfile("openmp-detect-", fileext = ".cpp")
+    writeLines("", con = script)
+    on.exit(unlink(script, force = TRUE), add = TRUE)
+
+    # get the C++ compiler from R
+    r <- file.path(R.home("bin"), "R")
+    output <- tryCatch(
+        system2(r, c("CMD", "SHLIB", "--dry-run", shQuote(script)), stdout = TRUE),
+        condition = identity
+    )
+    if (inherits(output, "condition"))
+        return(.openmpPluginDefault())
+
+    # extract the compiler invocation from the shlib output
+    # use some heuristics here...
+    index <- grep("make would use", output)
+    compile <- output[[index + 1L]]
+
+    # use everything up to the first include flag, which is normally
+    # the R headers from CPPFLAGS
+    idx <- regexpr(" -I", compile, fixed = TRUE)
+    cxx <- substring(compile, 1L, idx - 1L)
+
+    # check the compiler version
+    command <- paste(cxx, "--version")
+    version <- tryCatch(
+        system(command, intern = TRUE),
+        condition = identity
+    )
+    if (inherits(version, "condition"))
+        return(.openmpPluginDefault())
+
+    # if we're using Apple clang, use alternate flags
+    # assume libomp was installed following https://mac.r-project.org/openmp/
+    if (any(grepl("Apple clang", version))) {
+        cxxflags <- "-Xclang -fopenmp"
+        libs <- "-lomp"
+    }
+
+    # if we're using Homebrew clang, add in libomp include paths
+    else if (any(grepl("Homebrew clang", version))) {
+        machine <- Sys.info()[["machine"]]
+        prefix <- if (machine == "arm64") "/opt/homebrew" else "/usr/local"
+        cxxflags <- sprintf("-I%s/opt/libomp/include -fopenmp", prefix)
+        libs <- sprintf("-L%s/opt/libomp/lib -fopenmp", prefix)
+
+    # otherwise, use default -fopenmp flags for other compilers (LLVM clang; gcc)
+    } else {
+        cxxflags <- "-fopenmp"
+        libs <- "-fopenmp"
+    }
+
+    list(env = list(PKG_CXXFLAGS = cxxflags, PKG_LIBS = libs))
+
+}
+
 ## built-in OpenMP plugin
-.plugins[["openmp"]] <- function() {
-    list(env = list(PKG_CXXFLAGS="-fopenmp",
-                    PKG_LIBS="-fopenmp"))
+.plugins[["openmp"]] <- if (Sys.info()[["sysname"]] == "Darwin") {
+    .openmpPluginDarwin
+} else {
+    .openmpPluginDefault
 }
 
 .plugins[["unwindProtect"]] <- function() { # nocov start
@@ -1260,6 +1331,10 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
             if (!routine %in% routines) {
                 declaration <- grep(sprintf("^extern .* %s\\(.*$", routine), code,
                                     value = TRUE)
+                # FIXME: maybe we should extend this to *any* routine?
+                # or is there any case in which `void *` is not SEXP for a .Call?
+                if (routine == "run_testthat_tests")
+                    declaration <- gsub("void *", "SEXP", declaration, fixed=TRUE)
                 declarations <- c(declarations, sub("^extern", "RcppExport", declaration))
                 call_entries <- c(call_entries, match[[1]])			# #nocov end
             }
