@@ -41,13 +41,15 @@ public:
         const std::string& field_name ;
 
         SEXP get() const {
-            Shield<SEXP> call( Rf_lang3( R_DollarSymbol, parent, Rf_mkString(field_name.c_str()) ) ) ;
-            return Rcpp_eval( call, R_GlobalEnv ) ;
+            Shield<SEXP> str(Rf_mkString(field_name.c_str()));
+            Shield<SEXP> call(Rf_lang3(R_DollarSymbol, parent, str));
+            return Rcpp_fast_eval( call, R_GlobalEnv ) ;
         }
         void set(SEXP x ) {
             SEXP dollarGetsSym = Rf_install( "$<-");
-            Shield<SEXP> call( Rf_lang4( dollarGetsSym, parent, Rf_mkString(field_name.c_str()) , x ) ) ;
-            parent.set__( Rcpp_eval( call, R_GlobalEnv ) );
+            Shield<SEXP> str(Rf_mkString(field_name.c_str()));
+            Shield<SEXP> call(Rf_lang4(dollarGetsSym, parent, str, x));
+            parent.set__( Rcpp_fast_eval( call, R_GlobalEnv ) );
         }
     } ;
 
@@ -66,8 +68,9 @@ public:
         const std::string& field_name ;
 
         SEXP get() const {
-            Shield<SEXP> call( Rf_lang3( R_DollarSymbol, parent, Rf_mkString(field_name.c_str()) ) ) ;
-            return Rcpp_eval( call, R_GlobalEnv ) ;
+            Shield<SEXP> str(Rf_mkString(field_name.c_str()));
+            Shield<SEXP> call(Rf_lang3(R_DollarSymbol, parent, str));
+            return Rcpp_fast_eval( call, R_GlobalEnv ) ;
         }
     } ;
 
