@@ -1,8 +1,6 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
+// sets.h: Rcpp R/C++ interface class library --
 //
-// sets.h: Rcpp R/C++ interface class library -- 
-//
-// Copyright (C) 2012   Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2012 - 2025  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -22,15 +20,14 @@
 #ifndef Rcpp__sugar__sets_h
 #define Rcpp__sugar__sets_h
 
-#if __cplusplus >= 201103L
-    #define RCPP_UNORDERED_SET std::unordered_set
-    #define RCPP_UNORDERED_MAP std::unordered_map
-#elif defined(HAS_TR1_UNORDERED_SET)
-    #define RCPP_UNORDERED_SET std::tr1::unordered_set
-    #define RCPP_UNORDERED_MAP std::tr1::unordered_map
-#else
-    #define RCPP_UNORDERED_SET std::set
-    #define RCPP_UNORDERED_MAP std::map
-#endif
+namespace std {
+    template<>
+    struct hash<Rcpp::String> {
+        std::size_t operator()(const Rcpp::String& key) const {
+            return pointer_hasher( key.get_sexp() ) ;
+        }
+        hash<SEXP> pointer_hasher ;
+    };
+}
 
 #endif
